var Prefs = new Object();

Prefs.KEYCHAIN_KEY = "MindMeister Widget";

// Determines whether or not the widget is properly initialized.  It is
// considered properly initialized if there is an account found in the
// widget preferences and if there is a password for that account found in
// the Keychain.
Prefs.isInitialized = function() {
  // Get the account preference if one exists.  If not, return false.
  var account = Prefs.getAccount();
  if (account == null || account.length == 0) {
    return false;
  }

  // Get the password from the keychain if one exists.  If not, return false.
  var password = Prefs.getPassword(account);
  if (password == null || password.length == 0) {
    return false;
  }

  // Both are specified, so return true;
  return true;
}

// Removes all prefs.
Prefs.removeAll = function() {
  Prefs.setPassword(Prefs.getAccount(), null);
  Prefs.setAccount(null);
}

// Get the account for this instance of the widget.
Prefs.getAccount = function() {
  if (window.widget) {
    return widget.preferenceForKey("account:" + widget.identifier);
  }
}

// Set the account for this instance of the widget.
Prefs.setAccount = function(account) {
  if (window.widget) {
    widget.setPreferenceForKey(account, "account:" + widget.identifier);
  }
}

// Get the password for the given account.
Prefs.getPassword = function(account) {
  if (account == null) {
    return "";
  } else {
    return KeychainHelper.passwordForApplication(Prefs.KEYCHAIN_KEY,
        account.toLowerCase() + ":" + widget.identifier);
  }
}

// Set the password for the given account.
Prefs.setPassword = function(account, password) {
  if (account != null) {
    KeychainHelper.setPasswordForApplication(Prefs.KEYCHAIN_KEY,
        account.toLowerCase() + ":" + widget.identifier, password);
  }
}
